@@ -11,10 +11,17 @@ def loader(app: Flask):
     blueprints = app.config.get("BLUEPRINTS", [])
     import_name = get_import_name(app)
     for name in blueprints:
-        bp = import_name + name + ".routes.blueprint"
-        bp: Blueprint = import_attr(bp)
-        routes = import_name + name + ".urls.routes"
-        routes = import_attr(routes)
+        try:
+            bp = import_name + name + ".routes.blueprint"
+            bp: Blueprint = import_attr(bp)
+            routes = import_name + name + ".urls.routes"
+            routes = import_attr(routes)
+        except (ImportError, AttributeError):
+            bp = name + ".routes.blueprint"
+            bp: Blueprint = import_attr(bp)
+            routes = name + ".urls.routes"
+            routes = import_attr(routes)
+
         for url, view, methods in routes:
             bp.add_url_rule(url, view_func=view, methods=methods)
 
