@@ -1,10 +1,10 @@
 from datetime import datetime, timedelta
-from flask import url_for
-from flask_jwt_extended import create_access_token, decode_token
+from flask_jwt_extended import create_access_token, decode_token, get_raw_jwt
 from flask_apispec import use_kwargs, marshal_with
 from jwt import DecodeError, ExpiredSignatureError
+from marshmallow import fields
 from werkzeug.security import generate_password_hash, check_password_hash
-from zemfrog.decorators import auto_status_code
+from zemfrog.decorators import auto_status_code, authenticate
 from zemfrog.helper import db_add, db_update, db_commit, get_mail_template, get_user_roles
 from zemfrog.models import (
     DefaultResponseSchema,
@@ -15,35 +15,41 @@ from zemfrog.models import (
     RequestPasswordResetSchema,
 )
 
-from {{ "" if main_app else ".." }}models.user import User, Log
+from {{ "" if main_app else ".." }}extensions.marshmallow import ma
+from {{ "" if main_app else ".." }}models.user import User, Log, Role, Permission
 from {{ "" if main_app else ".." }}tasks.email import send_email
 
 
-@marshal_with(DefaultResponseSchema, 403)
-@marshal_with(DefaultResponseSchema, 401)
-@marshal_with(DefaultResponseSchema, 200)
-@auto_status_code
-def test_token(token):
+class PermissionSchema(ma.SQLAlchemyAutoSchema):
+    class Meta:
+        model = Permission
+
+
+class RoleSchema(ma.SQLAlchemyAutoSchema):
+    class Meta:
+        model = Role
+
+    permissions = fields.List(fields.Nested(PermissionSchema()))
+
+
+class UserDetailSchema(ma.SQLAlchemyAutoSchema):
+    class Meta:
+        model = User
+        exclude = ("password",)
+
+    roles = fields.List(fields.Nested(RoleSchema()))
+
+
+@authenticate()
+@marshal_with(UserDetailSchema)
+def user_detail():
     """
-    Test for jwt token.
+    User detail info.
     """
 
-    reason = "Valid token"
-    status_code = 200
-    try:
-        email = decode_token(token)["identity"]
-        user = User.query.filter_by(email=email).first()
-        if not user:
-            raise DecodeError
-
-    except DecodeError:
-        reason = "Invalid token"
-        status_code = 403
-    except ExpiredSignatureError:
-        reason = "Token expired"
-        status_code = 401
-
-    return {"reason": reason, "status_code": status_code}
+    email = get_raw_jwt().get("identity")
+    user = User.query.filter_by(email=email).first()
+    return user
 
 @use_kwargs(LoginSchema(), location="form")
 @marshal_with(DefaultResponseSchema, 404)
@@ -104,8 +110,7 @@ def register(**kwds):
                     expires_delta=False,
                     user_claims={"token_registration": True},
                 )
-                link_confirm = url_for(".confirm_account", token=token)
-                msg = get_mail_template("register.html", link_confirm=link_confirm)
+                msg = get_mail_template("register.html", token=token)
                 send_email.delay("Registration", html=msg, recipients=[email])
                 reason = "Successful registration."
                 status_code = 200
@@ -176,9 +181,8 @@ def request_password_reset(**kwds):
                 expires_delta=timedelta(hours=2),
                 user_claims={"token_password_reset": True},
             )
-            link_reset = url_for(".password_reset", token=token)
             msg = get_mail_template(
-                "request_password_reset.html", link_reset=link_reset
+                "request_password_reset.html", token=token
             )
             send_email.delay("Forgot password", html=msg, recipients=[email])
             log = Log(request_password_reset_at=datetime.utcnow())
